# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['WorkspaceArgs', 'Workspace']

@pulumi.input_type
class WorkspaceArgs:
    def __init__(__self__, *,
                 cost_estimation_enabled: pulumi.Input[_builtins.bool],
                 identifier: pulumi.Input[_builtins.str],
                 org_id: pulumi.Input[_builtins.str],
                 project_id: pulumi.Input[_builtins.str],
                 provisioner_type: pulumi.Input[_builtins.str],
                 provisioner_version: pulumi.Input[_builtins.str],
                 repository: pulumi.Input[_builtins.str],
                 repository_connector: pulumi.Input[_builtins.str],
                 repository_path: pulumi.Input[_builtins.str],
                 connectors: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceConnectorArgs']]]] = None,
                 default_pipelines: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 environment_variables: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceEnvironmentVariableArgs']]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_connector: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_branch: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_commit: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_sha: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 terraform_variable_files: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceTerraformVariableFileArgs']]]] = None,
                 terraform_variables: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceTerraformVariableArgs']]]] = None,
                 variable_sets: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a Workspace resource.
        :param pulumi.Input[_builtins.bool] cost_estimation_enabled: Cost estimation enabled determines if cost estimation operations are performed.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] repository: Repository is the name of the repository to fetch the code from.
        :param pulumi.Input[_builtins.str] repository_connector: Repository connector is the reference to the connector used to fetch the code.
        :param pulumi.Input[_builtins.str] repository_path: Repository path is the path in which the code resides.
        :param pulumi.Input[Sequence[pulumi.Input['WorkspaceConnectorArgs']]] connectors: Provider connectors configured on the Workspace. Only one connector of a type is supported
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] default_pipelines: Default pipelines associated with this workspace
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[Sequence[pulumi.Input['WorkspaceEnvironmentVariableArgs']]] environment_variables: Environment variables configured on the workspace
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] provider_connector: Provider connector is the reference to the connector for the infrastructure provider - this way of defining connector will be deprecated in the coming releases, use connector as block set.
        :param pulumi.Input[_builtins.str] repository_branch: Repository branch is the name of the branch to fetch the code from. This cannot be set if repository commit or sha is set.
        :param pulumi.Input[_builtins.str] repository_commit: Repository commit is tag to fetch the code from. This cannot be set if repository branch or sha is set.
        :param pulumi.Input[_builtins.str] repository_sha: Repository commit is commit SHA to fetch the code from. This cannot be set if repository branch or commit is set.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] variable_sets: Variable sets to use.
        """
        pulumi.set(__self__, "cost_estimation_enabled", cost_estimation_enabled)
        pulumi.set(__self__, "identifier", identifier)
        pulumi.set(__self__, "org_id", org_id)
        pulumi.set(__self__, "project_id", project_id)
        pulumi.set(__self__, "provisioner_type", provisioner_type)
        pulumi.set(__self__, "provisioner_version", provisioner_version)
        pulumi.set(__self__, "repository", repository)
        pulumi.set(__self__, "repository_connector", repository_connector)
        pulumi.set(__self__, "repository_path", repository_path)
        if connectors is not None:
            pulumi.set(__self__, "connectors", connectors)
        if default_pipelines is not None:
            pulumi.set(__self__, "default_pipelines", default_pipelines)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if environment_variables is not None:
            pulumi.set(__self__, "environment_variables", environment_variables)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if provider_connector is not None:
            pulumi.set(__self__, "provider_connector", provider_connector)
        if repository_branch is not None:
            pulumi.set(__self__, "repository_branch", repository_branch)
        if repository_commit is not None:
            pulumi.set(__self__, "repository_commit", repository_commit)
        if repository_sha is not None:
            pulumi.set(__self__, "repository_sha", repository_sha)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if terraform_variable_files is not None:
            pulumi.set(__self__, "terraform_variable_files", terraform_variable_files)
        if terraform_variables is not None:
            pulumi.set(__self__, "terraform_variables", terraform_variables)
        if variable_sets is not None:
            pulumi.set(__self__, "variable_sets", variable_sets)

    @_builtins.property
    @pulumi.getter(name="costEstimationEnabled")
    def cost_estimation_enabled(self) -> pulumi.Input[_builtins.bool]:
        """
        Cost estimation enabled determines if cost estimation operations are performed.
        """
        return pulumi.get(self, "cost_estimation_enabled")

    @cost_estimation_enabled.setter
    def cost_estimation_enabled(self, value: pulumi.Input[_builtins.bool]):
        pulumi.set(self, "cost_estimation_enabled", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="provisionerType")
    def provisioner_type(self) -> pulumi.Input[_builtins.str]:
        return pulumi.get(self, "provisioner_type")

    @provisioner_type.setter
    def provisioner_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "provisioner_type", value)

    @_builtins.property
    @pulumi.getter(name="provisionerVersion")
    def provisioner_version(self) -> pulumi.Input[_builtins.str]:
        return pulumi.get(self, "provisioner_version")

    @provisioner_version.setter
    def provisioner_version(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "provisioner_version", value)

    @_builtins.property
    @pulumi.getter
    def repository(self) -> pulumi.Input[_builtins.str]:
        """
        Repository is the name of the repository to fetch the code from.
        """
        return pulumi.get(self, "repository")

    @repository.setter
    def repository(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "repository", value)

    @_builtins.property
    @pulumi.getter(name="repositoryConnector")
    def repository_connector(self) -> pulumi.Input[_builtins.str]:
        """
        Repository connector is the reference to the connector used to fetch the code.
        """
        return pulumi.get(self, "repository_connector")

    @repository_connector.setter
    def repository_connector(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "repository_connector", value)

    @_builtins.property
    @pulumi.getter(name="repositoryPath")
    def repository_path(self) -> pulumi.Input[_builtins.str]:
        """
        Repository path is the path in which the code resides.
        """
        return pulumi.get(self, "repository_path")

    @repository_path.setter
    def repository_path(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "repository_path", value)

    @_builtins.property
    @pulumi.getter
    def connectors(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceConnectorArgs']]]]:
        """
        Provider connectors configured on the Workspace. Only one connector of a type is supported
        """
        return pulumi.get(self, "connectors")

    @connectors.setter
    def connectors(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceConnectorArgs']]]]):
        pulumi.set(self, "connectors", value)

    @_builtins.property
    @pulumi.getter(name="defaultPipelines")
    def default_pipelines(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        Default pipelines associated with this workspace
        """
        return pulumi.get(self, "default_pipelines")

    @default_pipelines.setter
    def default_pipelines(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "default_pipelines", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="environmentVariables")
    def environment_variables(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceEnvironmentVariableArgs']]]]:
        """
        Environment variables configured on the workspace
        """
        return pulumi.get(self, "environment_variables")

    @environment_variables.setter
    def environment_variables(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceEnvironmentVariableArgs']]]]):
        pulumi.set(self, "environment_variables", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="providerConnector")
    def provider_connector(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Provider connector is the reference to the connector for the infrastructure provider - this way of defining connector will be deprecated in the coming releases, use connector as block set.
        """
        return pulumi.get(self, "provider_connector")

    @provider_connector.setter
    def provider_connector(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "provider_connector", value)

    @_builtins.property
    @pulumi.getter(name="repositoryBranch")
    def repository_branch(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Repository branch is the name of the branch to fetch the code from. This cannot be set if repository commit or sha is set.
        """
        return pulumi.get(self, "repository_branch")

    @repository_branch.setter
    def repository_branch(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository_branch", value)

    @_builtins.property
    @pulumi.getter(name="repositoryCommit")
    def repository_commit(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Repository commit is tag to fetch the code from. This cannot be set if repository branch or sha is set.
        """
        return pulumi.get(self, "repository_commit")

    @repository_commit.setter
    def repository_commit(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository_commit", value)

    @_builtins.property
    @pulumi.getter(name="repositorySha")
    def repository_sha(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Repository commit is commit SHA to fetch the code from. This cannot be set if repository branch or commit is set.
        """
        return pulumi.get(self, "repository_sha")

    @repository_sha.setter
    def repository_sha(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository_sha", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="terraformVariableFiles")
    def terraform_variable_files(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceTerraformVariableFileArgs']]]]:
        return pulumi.get(self, "terraform_variable_files")

    @terraform_variable_files.setter
    def terraform_variable_files(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceTerraformVariableFileArgs']]]]):
        pulumi.set(self, "terraform_variable_files", value)

    @_builtins.property
    @pulumi.getter(name="terraformVariables")
    def terraform_variables(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceTerraformVariableArgs']]]]:
        return pulumi.get(self, "terraform_variables")

    @terraform_variables.setter
    def terraform_variables(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceTerraformVariableArgs']]]]):
        pulumi.set(self, "terraform_variables", value)

    @_builtins.property
    @pulumi.getter(name="variableSets")
    def variable_sets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Variable sets to use.
        """
        return pulumi.get(self, "variable_sets")

    @variable_sets.setter
    def variable_sets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "variable_sets", value)


@pulumi.input_type
class _WorkspaceState:
    def __init__(__self__, *,
                 connectors: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceConnectorArgs']]]] = None,
                 cost_estimation_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 default_pipelines: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 environment_variables: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceEnvironmentVariableArgs']]]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_connector: Optional[pulumi.Input[_builtins.str]] = None,
                 provisioner_type: Optional[pulumi.Input[_builtins.str]] = None,
                 provisioner_version: Optional[pulumi.Input[_builtins.str]] = None,
                 repository: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_branch: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_commit: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_connector: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_path: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_sha: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 terraform_variable_files: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceTerraformVariableFileArgs']]]] = None,
                 terraform_variables: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceTerraformVariableArgs']]]] = None,
                 variable_sets: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering Workspace resources.
        :param pulumi.Input[Sequence[pulumi.Input['WorkspaceConnectorArgs']]] connectors: Provider connectors configured on the Workspace. Only one connector of a type is supported
        :param pulumi.Input[_builtins.bool] cost_estimation_enabled: Cost estimation enabled determines if cost estimation operations are performed.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] default_pipelines: Default pipelines associated with this workspace
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[Sequence[pulumi.Input['WorkspaceEnvironmentVariableArgs']]] environment_variables: Environment variables configured on the workspace
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] provider_connector: Provider connector is the reference to the connector for the infrastructure provider - this way of defining connector will be deprecated in the coming releases, use connector as block set.
        :param pulumi.Input[_builtins.str] repository: Repository is the name of the repository to fetch the code from.
        :param pulumi.Input[_builtins.str] repository_branch: Repository branch is the name of the branch to fetch the code from. This cannot be set if repository commit or sha is set.
        :param pulumi.Input[_builtins.str] repository_commit: Repository commit is tag to fetch the code from. This cannot be set if repository branch or sha is set.
        :param pulumi.Input[_builtins.str] repository_connector: Repository connector is the reference to the connector used to fetch the code.
        :param pulumi.Input[_builtins.str] repository_path: Repository path is the path in which the code resides.
        :param pulumi.Input[_builtins.str] repository_sha: Repository commit is commit SHA to fetch the code from. This cannot be set if repository branch or commit is set.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] variable_sets: Variable sets to use.
        """
        if connectors is not None:
            pulumi.set(__self__, "connectors", connectors)
        if cost_estimation_enabled is not None:
            pulumi.set(__self__, "cost_estimation_enabled", cost_estimation_enabled)
        if default_pipelines is not None:
            pulumi.set(__self__, "default_pipelines", default_pipelines)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if environment_variables is not None:
            pulumi.set(__self__, "environment_variables", environment_variables)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if provider_connector is not None:
            pulumi.set(__self__, "provider_connector", provider_connector)
        if provisioner_type is not None:
            pulumi.set(__self__, "provisioner_type", provisioner_type)
        if provisioner_version is not None:
            pulumi.set(__self__, "provisioner_version", provisioner_version)
        if repository is not None:
            pulumi.set(__self__, "repository", repository)
        if repository_branch is not None:
            pulumi.set(__self__, "repository_branch", repository_branch)
        if repository_commit is not None:
            pulumi.set(__self__, "repository_commit", repository_commit)
        if repository_connector is not None:
            pulumi.set(__self__, "repository_connector", repository_connector)
        if repository_path is not None:
            pulumi.set(__self__, "repository_path", repository_path)
        if repository_sha is not None:
            pulumi.set(__self__, "repository_sha", repository_sha)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if terraform_variable_files is not None:
            pulumi.set(__self__, "terraform_variable_files", terraform_variable_files)
        if terraform_variables is not None:
            pulumi.set(__self__, "terraform_variables", terraform_variables)
        if variable_sets is not None:
            pulumi.set(__self__, "variable_sets", variable_sets)

    @_builtins.property
    @pulumi.getter
    def connectors(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceConnectorArgs']]]]:
        """
        Provider connectors configured on the Workspace. Only one connector of a type is supported
        """
        return pulumi.get(self, "connectors")

    @connectors.setter
    def connectors(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceConnectorArgs']]]]):
        pulumi.set(self, "connectors", value)

    @_builtins.property
    @pulumi.getter(name="costEstimationEnabled")
    def cost_estimation_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Cost estimation enabled determines if cost estimation operations are performed.
        """
        return pulumi.get(self, "cost_estimation_enabled")

    @cost_estimation_enabled.setter
    def cost_estimation_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "cost_estimation_enabled", value)

    @_builtins.property
    @pulumi.getter(name="defaultPipelines")
    def default_pipelines(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        Default pipelines associated with this workspace
        """
        return pulumi.get(self, "default_pipelines")

    @default_pipelines.setter
    def default_pipelines(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "default_pipelines", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="environmentVariables")
    def environment_variables(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceEnvironmentVariableArgs']]]]:
        """
        Environment variables configured on the workspace
        """
        return pulumi.get(self, "environment_variables")

    @environment_variables.setter
    def environment_variables(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceEnvironmentVariableArgs']]]]):
        pulumi.set(self, "environment_variables", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="providerConnector")
    def provider_connector(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Provider connector is the reference to the connector for the infrastructure provider - this way of defining connector will be deprecated in the coming releases, use connector as block set.
        """
        return pulumi.get(self, "provider_connector")

    @provider_connector.setter
    def provider_connector(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "provider_connector", value)

    @_builtins.property
    @pulumi.getter(name="provisionerType")
    def provisioner_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "provisioner_type")

    @provisioner_type.setter
    def provisioner_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "provisioner_type", value)

    @_builtins.property
    @pulumi.getter(name="provisionerVersion")
    def provisioner_version(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "provisioner_version")

    @provisioner_version.setter
    def provisioner_version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "provisioner_version", value)

    @_builtins.property
    @pulumi.getter
    def repository(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Repository is the name of the repository to fetch the code from.
        """
        return pulumi.get(self, "repository")

    @repository.setter
    def repository(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository", value)

    @_builtins.property
    @pulumi.getter(name="repositoryBranch")
    def repository_branch(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Repository branch is the name of the branch to fetch the code from. This cannot be set if repository commit or sha is set.
        """
        return pulumi.get(self, "repository_branch")

    @repository_branch.setter
    def repository_branch(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository_branch", value)

    @_builtins.property
    @pulumi.getter(name="repositoryCommit")
    def repository_commit(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Repository commit is tag to fetch the code from. This cannot be set if repository branch or sha is set.
        """
        return pulumi.get(self, "repository_commit")

    @repository_commit.setter
    def repository_commit(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository_commit", value)

    @_builtins.property
    @pulumi.getter(name="repositoryConnector")
    def repository_connector(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Repository connector is the reference to the connector used to fetch the code.
        """
        return pulumi.get(self, "repository_connector")

    @repository_connector.setter
    def repository_connector(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository_connector", value)

    @_builtins.property
    @pulumi.getter(name="repositoryPath")
    def repository_path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Repository path is the path in which the code resides.
        """
        return pulumi.get(self, "repository_path")

    @repository_path.setter
    def repository_path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository_path", value)

    @_builtins.property
    @pulumi.getter(name="repositorySha")
    def repository_sha(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Repository commit is commit SHA to fetch the code from. This cannot be set if repository branch or commit is set.
        """
        return pulumi.get(self, "repository_sha")

    @repository_sha.setter
    def repository_sha(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository_sha", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="terraformVariableFiles")
    def terraform_variable_files(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceTerraformVariableFileArgs']]]]:
        return pulumi.get(self, "terraform_variable_files")

    @terraform_variable_files.setter
    def terraform_variable_files(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceTerraformVariableFileArgs']]]]):
        pulumi.set(self, "terraform_variable_files", value)

    @_builtins.property
    @pulumi.getter(name="terraformVariables")
    def terraform_variables(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceTerraformVariableArgs']]]]:
        return pulumi.get(self, "terraform_variables")

    @terraform_variables.setter
    def terraform_variables(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceTerraformVariableArgs']]]]):
        pulumi.set(self, "terraform_variables", value)

    @_builtins.property
    @pulumi.getter(name="variableSets")
    def variable_sets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Variable sets to use.
        """
        return pulumi.get(self, "variable_sets")

    @variable_sets.setter
    def variable_sets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "variable_sets", value)


@pulumi.type_token("harness:platform/workspace:Workspace")
class Workspace(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 connectors: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceConnectorArgs', 'WorkspaceConnectorArgsDict']]]]] = None,
                 cost_estimation_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 default_pipelines: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 environment_variables: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceEnvironmentVariableArgs', 'WorkspaceEnvironmentVariableArgsDict']]]]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_connector: Optional[pulumi.Input[_builtins.str]] = None,
                 provisioner_type: Optional[pulumi.Input[_builtins.str]] = None,
                 provisioner_version: Optional[pulumi.Input[_builtins.str]] = None,
                 repository: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_branch: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_commit: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_connector: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_path: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_sha: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 terraform_variable_files: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceTerraformVariableFileArgs', 'WorkspaceTerraformVariableFileArgsDict']]]]] = None,
                 terraform_variables: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceTerraformVariableArgs', 'WorkspaceTerraformVariableArgsDict']]]]] = None,
                 variable_sets: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Resource for managing Workspaces

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.platform.Workspace("example",
            name="example",
            identifier="example",
            org_id=test_harness_platform_organization["id"],
            project_id=test_harness_platform_project["id"],
            provisioner_type="terraform",
            provisioner_version="1.5.6",
            repository="https://github.com/org/repo",
            repository_branch="main",
            repository_path="tf/aws/basic",
            cost_estimation_enabled=True,
            provider_connector=test["id"],
            repository_connector=test["id"],
            tags=[
                "tag1",
                "tag2",
            ],
            terraform_variables=[
                {
                    "key": "key1",
                    "value": "val1",
                    "value_type": "string",
                },
                {
                    "key": "key2",
                    "value": "val2",
                    "value_type": "string",
                },
            ],
            environment_variables=[
                {
                    "key": "key1",
                    "value": "val1",
                    "value_type": "string",
                },
                {
                    "key": "key2",
                    "value": "val2",
                    "value_type": "string",
                },
            ],
            terraform_variable_files=[
                {
                    "repository": "https://github.com/org/repo",
                    "repository_branch": "main",
                    "repository_path": "tf/gcp/basic",
                    "repository_connector": test["id"],
                },
                {
                    "repository": "https://github.com/org/repo",
                    "repository_commit": "v1.0.0",
                    "repository_path": "tf/aws/basic",
                    "repository_connector": test["id"],
                },
                {
                    "repository": "https://github.com/org/repo",
                    "repository_sha": "349d90bb9c90f4a3482981c259080de31609e6f6",
                    "repository_path": "tf/aws/basic",
                    "repository_connector": test["id"],
                },
            ],
            variable_sets=[test_harness_platform_infra_variable_set["id"]],
            default_pipelines={
                "destroy": "destroy_pipeline_id",
                "drift": "drift_pipeline_id",
                "plan": "plan_pipeline_id",
                "apply": "apply_pipeline_id",
            },
            connectors=[
                {
                    "connector_ref": "awsconnector",
                    "type": "aws",
                },
                {
                    "connector_ref": "gcpconnector",
                    "type": "gcp",
                },
                {
                    "connector_ref": "azureconnector",
                    "type": "azure",
                },
            ])
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        ```sh
        $ pulumi import harness:platform/workspace:Workspace example <org_id>/<project_id>/<workspace_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceConnectorArgs', 'WorkspaceConnectorArgsDict']]]] connectors: Provider connectors configured on the Workspace. Only one connector of a type is supported
        :param pulumi.Input[_builtins.bool] cost_estimation_enabled: Cost estimation enabled determines if cost estimation operations are performed.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] default_pipelines: Default pipelines associated with this workspace
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceEnvironmentVariableArgs', 'WorkspaceEnvironmentVariableArgsDict']]]] environment_variables: Environment variables configured on the workspace
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] provider_connector: Provider connector is the reference to the connector for the infrastructure provider - this way of defining connector will be deprecated in the coming releases, use connector as block set.
        :param pulumi.Input[_builtins.str] repository: Repository is the name of the repository to fetch the code from.
        :param pulumi.Input[_builtins.str] repository_branch: Repository branch is the name of the branch to fetch the code from. This cannot be set if repository commit or sha is set.
        :param pulumi.Input[_builtins.str] repository_commit: Repository commit is tag to fetch the code from. This cannot be set if repository branch or sha is set.
        :param pulumi.Input[_builtins.str] repository_connector: Repository connector is the reference to the connector used to fetch the code.
        :param pulumi.Input[_builtins.str] repository_path: Repository path is the path in which the code resides.
        :param pulumi.Input[_builtins.str] repository_sha: Repository commit is commit SHA to fetch the code from. This cannot be set if repository branch or commit is set.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] variable_sets: Variable sets to use.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: WorkspaceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for managing Workspaces

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.platform.Workspace("example",
            name="example",
            identifier="example",
            org_id=test_harness_platform_organization["id"],
            project_id=test_harness_platform_project["id"],
            provisioner_type="terraform",
            provisioner_version="1.5.6",
            repository="https://github.com/org/repo",
            repository_branch="main",
            repository_path="tf/aws/basic",
            cost_estimation_enabled=True,
            provider_connector=test["id"],
            repository_connector=test["id"],
            tags=[
                "tag1",
                "tag2",
            ],
            terraform_variables=[
                {
                    "key": "key1",
                    "value": "val1",
                    "value_type": "string",
                },
                {
                    "key": "key2",
                    "value": "val2",
                    "value_type": "string",
                },
            ],
            environment_variables=[
                {
                    "key": "key1",
                    "value": "val1",
                    "value_type": "string",
                },
                {
                    "key": "key2",
                    "value": "val2",
                    "value_type": "string",
                },
            ],
            terraform_variable_files=[
                {
                    "repository": "https://github.com/org/repo",
                    "repository_branch": "main",
                    "repository_path": "tf/gcp/basic",
                    "repository_connector": test["id"],
                },
                {
                    "repository": "https://github.com/org/repo",
                    "repository_commit": "v1.0.0",
                    "repository_path": "tf/aws/basic",
                    "repository_connector": test["id"],
                },
                {
                    "repository": "https://github.com/org/repo",
                    "repository_sha": "349d90bb9c90f4a3482981c259080de31609e6f6",
                    "repository_path": "tf/aws/basic",
                    "repository_connector": test["id"],
                },
            ],
            variable_sets=[test_harness_platform_infra_variable_set["id"]],
            default_pipelines={
                "destroy": "destroy_pipeline_id",
                "drift": "drift_pipeline_id",
                "plan": "plan_pipeline_id",
                "apply": "apply_pipeline_id",
            },
            connectors=[
                {
                    "connector_ref": "awsconnector",
                    "type": "aws",
                },
                {
                    "connector_ref": "gcpconnector",
                    "type": "gcp",
                },
                {
                    "connector_ref": "azureconnector",
                    "type": "azure",
                },
            ])
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        ```sh
        $ pulumi import harness:platform/workspace:Workspace example <org_id>/<project_id>/<workspace_id>
        ```

        :param str resource_name: The name of the resource.
        :param WorkspaceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(WorkspaceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 connectors: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceConnectorArgs', 'WorkspaceConnectorArgsDict']]]]] = None,
                 cost_estimation_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 default_pipelines: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 environment_variables: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceEnvironmentVariableArgs', 'WorkspaceEnvironmentVariableArgsDict']]]]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_connector: Optional[pulumi.Input[_builtins.str]] = None,
                 provisioner_type: Optional[pulumi.Input[_builtins.str]] = None,
                 provisioner_version: Optional[pulumi.Input[_builtins.str]] = None,
                 repository: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_branch: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_commit: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_connector: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_path: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_sha: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 terraform_variable_files: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceTerraformVariableFileArgs', 'WorkspaceTerraformVariableFileArgsDict']]]]] = None,
                 terraform_variables: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceTerraformVariableArgs', 'WorkspaceTerraformVariableArgsDict']]]]] = None,
                 variable_sets: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = WorkspaceArgs.__new__(WorkspaceArgs)

            __props__.__dict__["connectors"] = connectors
            if cost_estimation_enabled is None and not opts.urn:
                raise TypeError("Missing required property 'cost_estimation_enabled'")
            __props__.__dict__["cost_estimation_enabled"] = cost_estimation_enabled
            __props__.__dict__["default_pipelines"] = default_pipelines
            __props__.__dict__["description"] = description
            __props__.__dict__["environment_variables"] = environment_variables
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["name"] = name
            if org_id is None and not opts.urn:
                raise TypeError("Missing required property 'org_id'")
            __props__.__dict__["org_id"] = org_id
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["provider_connector"] = provider_connector
            if provisioner_type is None and not opts.urn:
                raise TypeError("Missing required property 'provisioner_type'")
            __props__.__dict__["provisioner_type"] = provisioner_type
            if provisioner_version is None and not opts.urn:
                raise TypeError("Missing required property 'provisioner_version'")
            __props__.__dict__["provisioner_version"] = provisioner_version
            if repository is None and not opts.urn:
                raise TypeError("Missing required property 'repository'")
            __props__.__dict__["repository"] = repository
            __props__.__dict__["repository_branch"] = repository_branch
            __props__.__dict__["repository_commit"] = repository_commit
            if repository_connector is None and not opts.urn:
                raise TypeError("Missing required property 'repository_connector'")
            __props__.__dict__["repository_connector"] = repository_connector
            if repository_path is None and not opts.urn:
                raise TypeError("Missing required property 'repository_path'")
            __props__.__dict__["repository_path"] = repository_path
            __props__.__dict__["repository_sha"] = repository_sha
            __props__.__dict__["tags"] = tags
            __props__.__dict__["terraform_variable_files"] = terraform_variable_files
            __props__.__dict__["terraform_variables"] = terraform_variables
            __props__.__dict__["variable_sets"] = variable_sets
        super(Workspace, __self__).__init__(
            'harness:platform/workspace:Workspace',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            connectors: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceConnectorArgs', 'WorkspaceConnectorArgsDict']]]]] = None,
            cost_estimation_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            default_pipelines: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            environment_variables: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceEnvironmentVariableArgs', 'WorkspaceEnvironmentVariableArgsDict']]]]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            provider_connector: Optional[pulumi.Input[_builtins.str]] = None,
            provisioner_type: Optional[pulumi.Input[_builtins.str]] = None,
            provisioner_version: Optional[pulumi.Input[_builtins.str]] = None,
            repository: Optional[pulumi.Input[_builtins.str]] = None,
            repository_branch: Optional[pulumi.Input[_builtins.str]] = None,
            repository_commit: Optional[pulumi.Input[_builtins.str]] = None,
            repository_connector: Optional[pulumi.Input[_builtins.str]] = None,
            repository_path: Optional[pulumi.Input[_builtins.str]] = None,
            repository_sha: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            terraform_variable_files: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceTerraformVariableFileArgs', 'WorkspaceTerraformVariableFileArgsDict']]]]] = None,
            terraform_variables: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceTerraformVariableArgs', 'WorkspaceTerraformVariableArgsDict']]]]] = None,
            variable_sets: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'Workspace':
        """
        Get an existing Workspace resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceConnectorArgs', 'WorkspaceConnectorArgsDict']]]] connectors: Provider connectors configured on the Workspace. Only one connector of a type is supported
        :param pulumi.Input[_builtins.bool] cost_estimation_enabled: Cost estimation enabled determines if cost estimation operations are performed.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] default_pipelines: Default pipelines associated with this workspace
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceEnvironmentVariableArgs', 'WorkspaceEnvironmentVariableArgsDict']]]] environment_variables: Environment variables configured on the workspace
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] provider_connector: Provider connector is the reference to the connector for the infrastructure provider - this way of defining connector will be deprecated in the coming releases, use connector as block set.
        :param pulumi.Input[_builtins.str] repository: Repository is the name of the repository to fetch the code from.
        :param pulumi.Input[_builtins.str] repository_branch: Repository branch is the name of the branch to fetch the code from. This cannot be set if repository commit or sha is set.
        :param pulumi.Input[_builtins.str] repository_commit: Repository commit is tag to fetch the code from. This cannot be set if repository branch or sha is set.
        :param pulumi.Input[_builtins.str] repository_connector: Repository connector is the reference to the connector used to fetch the code.
        :param pulumi.Input[_builtins.str] repository_path: Repository path is the path in which the code resides.
        :param pulumi.Input[_builtins.str] repository_sha: Repository commit is commit SHA to fetch the code from. This cannot be set if repository branch or commit is set.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] variable_sets: Variable sets to use.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _WorkspaceState.__new__(_WorkspaceState)

        __props__.__dict__["connectors"] = connectors
        __props__.__dict__["cost_estimation_enabled"] = cost_estimation_enabled
        __props__.__dict__["default_pipelines"] = default_pipelines
        __props__.__dict__["description"] = description
        __props__.__dict__["environment_variables"] = environment_variables
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["provider_connector"] = provider_connector
        __props__.__dict__["provisioner_type"] = provisioner_type
        __props__.__dict__["provisioner_version"] = provisioner_version
        __props__.__dict__["repository"] = repository
        __props__.__dict__["repository_branch"] = repository_branch
        __props__.__dict__["repository_commit"] = repository_commit
        __props__.__dict__["repository_connector"] = repository_connector
        __props__.__dict__["repository_path"] = repository_path
        __props__.__dict__["repository_sha"] = repository_sha
        __props__.__dict__["tags"] = tags
        __props__.__dict__["terraform_variable_files"] = terraform_variable_files
        __props__.__dict__["terraform_variables"] = terraform_variables
        __props__.__dict__["variable_sets"] = variable_sets
        return Workspace(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def connectors(self) -> pulumi.Output[Optional[Sequence['outputs.WorkspaceConnector']]]:
        """
        Provider connectors configured on the Workspace. Only one connector of a type is supported
        """
        return pulumi.get(self, "connectors")

    @_builtins.property
    @pulumi.getter(name="costEstimationEnabled")
    def cost_estimation_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Cost estimation enabled determines if cost estimation operations are performed.
        """
        return pulumi.get(self, "cost_estimation_enabled")

    @_builtins.property
    @pulumi.getter(name="defaultPipelines")
    def default_pipelines(self) -> pulumi.Output[Optional[Mapping[str, _builtins.str]]]:
        """
        Default pipelines associated with this workspace
        """
        return pulumi.get(self, "default_pipelines")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="environmentVariables")
    def environment_variables(self) -> pulumi.Output[Optional[Sequence['outputs.WorkspaceEnvironmentVariable']]]:
        """
        Environment variables configured on the workspace
        """
        return pulumi.get(self, "environment_variables")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="providerConnector")
    def provider_connector(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Provider connector is the reference to the connector for the infrastructure provider - this way of defining connector will be deprecated in the coming releases, use connector as block set.
        """
        return pulumi.get(self, "provider_connector")

    @_builtins.property
    @pulumi.getter(name="provisionerType")
    def provisioner_type(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "provisioner_type")

    @_builtins.property
    @pulumi.getter(name="provisionerVersion")
    def provisioner_version(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "provisioner_version")

    @_builtins.property
    @pulumi.getter
    def repository(self) -> pulumi.Output[_builtins.str]:
        """
        Repository is the name of the repository to fetch the code from.
        """
        return pulumi.get(self, "repository")

    @_builtins.property
    @pulumi.getter(name="repositoryBranch")
    def repository_branch(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Repository branch is the name of the branch to fetch the code from. This cannot be set if repository commit or sha is set.
        """
        return pulumi.get(self, "repository_branch")

    @_builtins.property
    @pulumi.getter(name="repositoryCommit")
    def repository_commit(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Repository commit is tag to fetch the code from. This cannot be set if repository branch or sha is set.
        """
        return pulumi.get(self, "repository_commit")

    @_builtins.property
    @pulumi.getter(name="repositoryConnector")
    def repository_connector(self) -> pulumi.Output[_builtins.str]:
        """
        Repository connector is the reference to the connector used to fetch the code.
        """
        return pulumi.get(self, "repository_connector")

    @_builtins.property
    @pulumi.getter(name="repositoryPath")
    def repository_path(self) -> pulumi.Output[_builtins.str]:
        """
        Repository path is the path in which the code resides.
        """
        return pulumi.get(self, "repository_path")

    @_builtins.property
    @pulumi.getter(name="repositorySha")
    def repository_sha(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Repository commit is commit SHA to fetch the code from. This cannot be set if repository branch or commit is set.
        """
        return pulumi.get(self, "repository_sha")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="terraformVariableFiles")
    def terraform_variable_files(self) -> pulumi.Output[Optional[Sequence['outputs.WorkspaceTerraformVariableFile']]]:
        return pulumi.get(self, "terraform_variable_files")

    @_builtins.property
    @pulumi.getter(name="terraformVariables")
    def terraform_variables(self) -> pulumi.Output[Optional[Sequence['outputs.WorkspaceTerraformVariable']]]:
        return pulumi.get(self, "terraform_variables")

    @_builtins.property
    @pulumi.getter(name="variableSets")
    def variable_sets(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Variable sets to use.
        """
        return pulumi.get(self, "variable_sets")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['RuleRdsArgs', 'RuleRds']

@pulumi.input_type
class RuleRdsArgs:
    def __init__(__self__, *,
                 cloud_connector_id: pulumi.Input[_builtins.str],
                 database: pulumi.Input['RuleRdsDatabaseArgs'],
                 depends: Optional[pulumi.Input[Sequence[pulumi.Input['RuleRdsDependArgs']]]] = None,
                 dry_run: Optional[pulumi.Input[_builtins.bool]] = None,
                 idle_time_mins: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 tcps: Optional[pulumi.Input[Sequence[pulumi.Input['RuleRdsTcpArgs']]]] = None):
        """
        The set of arguments for constructing a RuleRds resource.
        :param pulumi.Input[_builtins.str] cloud_connector_id: Id of the cloud connector
        :param pulumi.Input[Sequence[pulumi.Input['RuleRdsDependArgs']]] depends: Dependent rules
        :param pulumi.Input[_builtins.bool] dry_run: Boolean that indicates whether the AutoStopping rule should be created in DryRun mode
        :param pulumi.Input[_builtins.int] idle_time_mins: Idle time in minutes. This is the time that the AutoStopping rule waits before stopping the idle instances.
        :param pulumi.Input[_builtins.str] name: Name of the rule
        :param pulumi.Input[Sequence[pulumi.Input['RuleRdsTcpArgs']]] tcps: TCP routing configuration
        """
        pulumi.set(__self__, "cloud_connector_id", cloud_connector_id)
        pulumi.set(__self__, "database", database)
        if depends is not None:
            pulumi.set(__self__, "depends", depends)
        if dry_run is not None:
            pulumi.set(__self__, "dry_run", dry_run)
        if idle_time_mins is not None:
            pulumi.set(__self__, "idle_time_mins", idle_time_mins)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if tcps is not None:
            pulumi.set(__self__, "tcps", tcps)

    @_builtins.property
    @pulumi.getter(name="cloudConnectorId")
    def cloud_connector_id(self) -> pulumi.Input[_builtins.str]:
        """
        Id of the cloud connector
        """
        return pulumi.get(self, "cloud_connector_id")

    @cloud_connector_id.setter
    def cloud_connector_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "cloud_connector_id", value)

    @_builtins.property
    @pulumi.getter
    def database(self) -> pulumi.Input['RuleRdsDatabaseArgs']:
        return pulumi.get(self, "database")

    @database.setter
    def database(self, value: pulumi.Input['RuleRdsDatabaseArgs']):
        pulumi.set(self, "database", value)

    @_builtins.property
    @pulumi.getter
    def depends(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RuleRdsDependArgs']]]]:
        """
        Dependent rules
        """
        return pulumi.get(self, "depends")

    @depends.setter
    def depends(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RuleRdsDependArgs']]]]):
        pulumi.set(self, "depends", value)

    @_builtins.property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Boolean that indicates whether the AutoStopping rule should be created in DryRun mode
        """
        return pulumi.get(self, "dry_run")

    @dry_run.setter
    def dry_run(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "dry_run", value)

    @_builtins.property
    @pulumi.getter(name="idleTimeMins")
    def idle_time_mins(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Idle time in minutes. This is the time that the AutoStopping rule waits before stopping the idle instances.
        """
        return pulumi.get(self, "idle_time_mins")

    @idle_time_mins.setter
    def idle_time_mins(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "idle_time_mins", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the rule
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def tcps(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RuleRdsTcpArgs']]]]:
        """
        TCP routing configuration
        """
        return pulumi.get(self, "tcps")

    @tcps.setter
    def tcps(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RuleRdsTcpArgs']]]]):
        pulumi.set(self, "tcps", value)


@pulumi.input_type
class _RuleRdsState:
    def __init__(__self__, *,
                 cloud_connector_id: Optional[pulumi.Input[_builtins.str]] = None,
                 database: Optional[pulumi.Input['RuleRdsDatabaseArgs']] = None,
                 depends: Optional[pulumi.Input[Sequence[pulumi.Input['RuleRdsDependArgs']]]] = None,
                 dry_run: Optional[pulumi.Input[_builtins.bool]] = None,
                 identifier: Optional[pulumi.Input[_builtins.float]] = None,
                 idle_time_mins: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 tcps: Optional[pulumi.Input[Sequence[pulumi.Input['RuleRdsTcpArgs']]]] = None):
        """
        Input properties used for looking up and filtering RuleRds resources.
        :param pulumi.Input[_builtins.str] cloud_connector_id: Id of the cloud connector
        :param pulumi.Input[Sequence[pulumi.Input['RuleRdsDependArgs']]] depends: Dependent rules
        :param pulumi.Input[_builtins.bool] dry_run: Boolean that indicates whether the AutoStopping rule should be created in DryRun mode
        :param pulumi.Input[_builtins.float] identifier: Unique identifier of the resource
        :param pulumi.Input[_builtins.int] idle_time_mins: Idle time in minutes. This is the time that the AutoStopping rule waits before stopping the idle instances.
        :param pulumi.Input[_builtins.str] name: Name of the rule
        :param pulumi.Input[Sequence[pulumi.Input['RuleRdsTcpArgs']]] tcps: TCP routing configuration
        """
        if cloud_connector_id is not None:
            pulumi.set(__self__, "cloud_connector_id", cloud_connector_id)
        if database is not None:
            pulumi.set(__self__, "database", database)
        if depends is not None:
            pulumi.set(__self__, "depends", depends)
        if dry_run is not None:
            pulumi.set(__self__, "dry_run", dry_run)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if idle_time_mins is not None:
            pulumi.set(__self__, "idle_time_mins", idle_time_mins)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if tcps is not None:
            pulumi.set(__self__, "tcps", tcps)

    @_builtins.property
    @pulumi.getter(name="cloudConnectorId")
    def cloud_connector_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Id of the cloud connector
        """
        return pulumi.get(self, "cloud_connector_id")

    @cloud_connector_id.setter
    def cloud_connector_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cloud_connector_id", value)

    @_builtins.property
    @pulumi.getter
    def database(self) -> Optional[pulumi.Input['RuleRdsDatabaseArgs']]:
        return pulumi.get(self, "database")

    @database.setter
    def database(self, value: Optional[pulumi.Input['RuleRdsDatabaseArgs']]):
        pulumi.set(self, "database", value)

    @_builtins.property
    @pulumi.getter
    def depends(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RuleRdsDependArgs']]]]:
        """
        Dependent rules
        """
        return pulumi.get(self, "depends")

    @depends.setter
    def depends(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RuleRdsDependArgs']]]]):
        pulumi.set(self, "depends", value)

    @_builtins.property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Boolean that indicates whether the AutoStopping rule should be created in DryRun mode
        """
        return pulumi.get(self, "dry_run")

    @dry_run.setter
    def dry_run(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "dry_run", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.float]]:
        """
        Unique identifier of the resource
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.float]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="idleTimeMins")
    def idle_time_mins(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Idle time in minutes. This is the time that the AutoStopping rule waits before stopping the idle instances.
        """
        return pulumi.get(self, "idle_time_mins")

    @idle_time_mins.setter
    def idle_time_mins(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "idle_time_mins", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the rule
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def tcps(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RuleRdsTcpArgs']]]]:
        """
        TCP routing configuration
        """
        return pulumi.get(self, "tcps")

    @tcps.setter
    def tcps(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RuleRdsTcpArgs']]]]):
        pulumi.set(self, "tcps", value)


@pulumi.type_token("harness:autostopping/ruleRds:RuleRds")
class RuleRds(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cloud_connector_id: Optional[pulumi.Input[_builtins.str]] = None,
                 database: Optional[pulumi.Input[Union['RuleRdsDatabaseArgs', 'RuleRdsDatabaseArgsDict']]] = None,
                 depends: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RuleRdsDependArgs', 'RuleRdsDependArgsDict']]]]] = None,
                 dry_run: Optional[pulumi.Input[_builtins.bool]] = None,
                 idle_time_mins: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 tcps: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RuleRdsTcpArgs', 'RuleRdsTcpArgsDict']]]]] = None,
                 __props__=None):
        """
        Resource for creating a AutoStopping rule for RDS databases.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        test = harness.autostopping.RuleRds("test",
            name="name",
            cloud_connector_id="cloud_connector_id",
            idle_time_mins=10,
            dry_run=True,
            database={
                "id": "database_id",
                "region": "region",
            },
            tcps=[{
                "proxy_id": "proxy_id",
                "forward_rules": [{
                    "port": 2233,
                }],
            }])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] cloud_connector_id: Id of the cloud connector
        :param pulumi.Input[Sequence[pulumi.Input[Union['RuleRdsDependArgs', 'RuleRdsDependArgsDict']]]] depends: Dependent rules
        :param pulumi.Input[_builtins.bool] dry_run: Boolean that indicates whether the AutoStopping rule should be created in DryRun mode
        :param pulumi.Input[_builtins.int] idle_time_mins: Idle time in minutes. This is the time that the AutoStopping rule waits before stopping the idle instances.
        :param pulumi.Input[_builtins.str] name: Name of the rule
        :param pulumi.Input[Sequence[pulumi.Input[Union['RuleRdsTcpArgs', 'RuleRdsTcpArgsDict']]]] tcps: TCP routing configuration
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RuleRdsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating a AutoStopping rule for RDS databases.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        test = harness.autostopping.RuleRds("test",
            name="name",
            cloud_connector_id="cloud_connector_id",
            idle_time_mins=10,
            dry_run=True,
            database={
                "id": "database_id",
                "region": "region",
            },
            tcps=[{
                "proxy_id": "proxy_id",
                "forward_rules": [{
                    "port": 2233,
                }],
            }])
        ```

        :param str resource_name: The name of the resource.
        :param RuleRdsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RuleRdsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cloud_connector_id: Optional[pulumi.Input[_builtins.str]] = None,
                 database: Optional[pulumi.Input[Union['RuleRdsDatabaseArgs', 'RuleRdsDatabaseArgsDict']]] = None,
                 depends: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RuleRdsDependArgs', 'RuleRdsDependArgsDict']]]]] = None,
                 dry_run: Optional[pulumi.Input[_builtins.bool]] = None,
                 idle_time_mins: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 tcps: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RuleRdsTcpArgs', 'RuleRdsTcpArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RuleRdsArgs.__new__(RuleRdsArgs)

            if cloud_connector_id is None and not opts.urn:
                raise TypeError("Missing required property 'cloud_connector_id'")
            __props__.__dict__["cloud_connector_id"] = cloud_connector_id
            if database is None and not opts.urn:
                raise TypeError("Missing required property 'database'")
            __props__.__dict__["database"] = database
            __props__.__dict__["depends"] = depends
            __props__.__dict__["dry_run"] = dry_run
            __props__.__dict__["idle_time_mins"] = idle_time_mins
            __props__.__dict__["name"] = name
            __props__.__dict__["tcps"] = tcps
            __props__.__dict__["identifier"] = None
        super(RuleRds, __self__).__init__(
            'harness:autostopping/ruleRds:RuleRds',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cloud_connector_id: Optional[pulumi.Input[_builtins.str]] = None,
            database: Optional[pulumi.Input[Union['RuleRdsDatabaseArgs', 'RuleRdsDatabaseArgsDict']]] = None,
            depends: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RuleRdsDependArgs', 'RuleRdsDependArgsDict']]]]] = None,
            dry_run: Optional[pulumi.Input[_builtins.bool]] = None,
            identifier: Optional[pulumi.Input[_builtins.float]] = None,
            idle_time_mins: Optional[pulumi.Input[_builtins.int]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            tcps: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RuleRdsTcpArgs', 'RuleRdsTcpArgsDict']]]]] = None) -> 'RuleRds':
        """
        Get an existing RuleRds resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] cloud_connector_id: Id of the cloud connector
        :param pulumi.Input[Sequence[pulumi.Input[Union['RuleRdsDependArgs', 'RuleRdsDependArgsDict']]]] depends: Dependent rules
        :param pulumi.Input[_builtins.bool] dry_run: Boolean that indicates whether the AutoStopping rule should be created in DryRun mode
        :param pulumi.Input[_builtins.float] identifier: Unique identifier of the resource
        :param pulumi.Input[_builtins.int] idle_time_mins: Idle time in minutes. This is the time that the AutoStopping rule waits before stopping the idle instances.
        :param pulumi.Input[_builtins.str] name: Name of the rule
        :param pulumi.Input[Sequence[pulumi.Input[Union['RuleRdsTcpArgs', 'RuleRdsTcpArgsDict']]]] tcps: TCP routing configuration
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RuleRdsState.__new__(_RuleRdsState)

        __props__.__dict__["cloud_connector_id"] = cloud_connector_id
        __props__.__dict__["database"] = database
        __props__.__dict__["depends"] = depends
        __props__.__dict__["dry_run"] = dry_run
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["idle_time_mins"] = idle_time_mins
        __props__.__dict__["name"] = name
        __props__.__dict__["tcps"] = tcps
        return RuleRds(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="cloudConnectorId")
    def cloud_connector_id(self) -> pulumi.Output[_builtins.str]:
        """
        Id of the cloud connector
        """
        return pulumi.get(self, "cloud_connector_id")

    @_builtins.property
    @pulumi.getter
    def database(self) -> pulumi.Output['outputs.RuleRdsDatabase']:
        return pulumi.get(self, "database")

    @_builtins.property
    @pulumi.getter
    def depends(self) -> pulumi.Output[Optional[Sequence['outputs.RuleRdsDepend']]]:
        """
        Dependent rules
        """
        return pulumi.get(self, "depends")

    @_builtins.property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Boolean that indicates whether the AutoStopping rule should be created in DryRun mode
        """
        return pulumi.get(self, "dry_run")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.float]:
        """
        Unique identifier of the resource
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="idleTimeMins")
    def idle_time_mins(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        Idle time in minutes. This is the time that the AutoStopping rule waits before stopping the idle instances.
        """
        return pulumi.get(self, "idle_time_mins")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the rule
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def tcps(self) -> pulumi.Output[Optional[Sequence['outputs.RuleRdsTcp']]]:
        """
        TCP routing configuration
        """
        return pulumi.get(self, "tcps")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['GitOpsRepositoryArgs', 'GitOpsRepository']

@pulumi.input_type
class GitOpsRepositoryArgs:
    def __init__(__self__, *,
                 agent_id: pulumi.Input[_builtins.str],
                 identifier: pulumi.Input[_builtins.str],
                 repos: pulumi.Input[Sequence[pulumi.Input['GitOpsRepositoryRepoArgs']]],
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 creds_only: Optional[pulumi.Input[_builtins.bool]] = None,
                 ecr_gen: Optional[pulumi.Input['GitOpsRepositoryEcrGenArgs']] = None,
                 force_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 gcr_gen: Optional[pulumi.Input['GitOpsRepositoryGcrGenArgs']] = None,
                 gen_type: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 refresh_interval: Optional[pulumi.Input[_builtins.str]] = None,
                 update_masks: Optional[pulumi.Input[Sequence[pulumi.Input['GitOpsRepositoryUpdateMaskArgs']]]] = None,
                 upsert: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a GitOpsRepository resource.
        :param pulumi.Input[_builtins.str] agent_id: Agent identifier of the GitOps repository.
        :param pulumi.Input[_builtins.str] identifier: Identifier of the GitOps repository.
        :param pulumi.Input[Sequence[pulumi.Input['GitOpsRepositoryRepoArgs']]] repos: Repo details holding application configurations.
        :param pulumi.Input[_builtins.str] account_id: Account identifier of the GitOps repository.
        :param pulumi.Input[_builtins.bool] creds_only: Indicates if to operate on credential set instead of repository.
        :param pulumi.Input['GitOpsRepositoryEcrGenArgs'] ecr_gen: ECR access token generator specific configuration.
        :param pulumi.Input[_builtins.bool] force_delete: Indicates if the repository should be deleted forcefully, regardless of existing applications using that repo.
        :param pulumi.Input['GitOpsRepositoryGcrGenArgs'] gcr_gen: GCR access token generator specific configuration.
        :param pulumi.Input[_builtins.str] gen_type: Default: "UNSET"
               Enum: "UNSET" "AWS*ECR" "GOOGLE*GCR"
        :param pulumi.Input[_builtins.str] org_id: Organization identifier of the GitOps repository.
        :param pulumi.Input[_builtins.str] project_id: Project identifier of the GitOps repository.
        :param pulumi.Input[_builtins.str] refresh_interval: For OCI repos, this is the interval to refresh the token to access the registry.
        :param pulumi.Input[Sequence[pulumi.Input['GitOpsRepositoryUpdateMaskArgs']]] update_masks: Update mask of the repository.
        :param pulumi.Input[_builtins.bool] upsert: Indicates if the GitOps repository should be updated if existing and inserted if not.
        """
        pulumi.set(__self__, "agent_id", agent_id)
        pulumi.set(__self__, "identifier", identifier)
        pulumi.set(__self__, "repos", repos)
        if account_id is not None:
            warnings.warn("""This field is deprecated and will be removed in a future release.""", DeprecationWarning)
            pulumi.log.warn("""account_id is deprecated: This field is deprecated and will be removed in a future release.""")
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if creds_only is not None:
            pulumi.set(__self__, "creds_only", creds_only)
        if ecr_gen is not None:
            pulumi.set(__self__, "ecr_gen", ecr_gen)
        if force_delete is not None:
            pulumi.set(__self__, "force_delete", force_delete)
        if gcr_gen is not None:
            pulumi.set(__self__, "gcr_gen", gcr_gen)
        if gen_type is not None:
            pulumi.set(__self__, "gen_type", gen_type)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if refresh_interval is not None:
            pulumi.set(__self__, "refresh_interval", refresh_interval)
        if update_masks is not None:
            warnings.warn("""This field is deprecated and will be removed in a future release.""", DeprecationWarning)
            pulumi.log.warn("""update_masks is deprecated: This field is deprecated and will be removed in a future release.""")
        if update_masks is not None:
            pulumi.set(__self__, "update_masks", update_masks)
        if upsert is not None:
            pulumi.set(__self__, "upsert", upsert)

    @_builtins.property
    @pulumi.getter(name="agentId")
    def agent_id(self) -> pulumi.Input[_builtins.str]:
        """
        Agent identifier of the GitOps repository.
        """
        return pulumi.get(self, "agent_id")

    @agent_id.setter
    def agent_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "agent_id", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Identifier of the GitOps repository.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def repos(self) -> pulumi.Input[Sequence[pulumi.Input['GitOpsRepositoryRepoArgs']]]:
        """
        Repo details holding application configurations.
        """
        return pulumi.get(self, "repos")

    @repos.setter
    def repos(self, value: pulumi.Input[Sequence[pulumi.Input['GitOpsRepositoryRepoArgs']]]):
        pulumi.set(self, "repos", value)

    @_builtins.property
    @pulumi.getter(name="accountId")
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release.""")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Account identifier of the GitOps repository.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter(name="credsOnly")
    def creds_only(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates if to operate on credential set instead of repository.
        """
        return pulumi.get(self, "creds_only")

    @creds_only.setter
    def creds_only(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "creds_only", value)

    @_builtins.property
    @pulumi.getter(name="ecrGen")
    def ecr_gen(self) -> Optional[pulumi.Input['GitOpsRepositoryEcrGenArgs']]:
        """
        ECR access token generator specific configuration.
        """
        return pulumi.get(self, "ecr_gen")

    @ecr_gen.setter
    def ecr_gen(self, value: Optional[pulumi.Input['GitOpsRepositoryEcrGenArgs']]):
        pulumi.set(self, "ecr_gen", value)

    @_builtins.property
    @pulumi.getter(name="forceDelete")
    def force_delete(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates if the repository should be deleted forcefully, regardless of existing applications using that repo.
        """
        return pulumi.get(self, "force_delete")

    @force_delete.setter
    def force_delete(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "force_delete", value)

    @_builtins.property
    @pulumi.getter(name="gcrGen")
    def gcr_gen(self) -> Optional[pulumi.Input['GitOpsRepositoryGcrGenArgs']]:
        """
        GCR access token generator specific configuration.
        """
        return pulumi.get(self, "gcr_gen")

    @gcr_gen.setter
    def gcr_gen(self, value: Optional[pulumi.Input['GitOpsRepositoryGcrGenArgs']]):
        pulumi.set(self, "gcr_gen", value)

    @_builtins.property
    @pulumi.getter(name="genType")
    def gen_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Default: "UNSET"
        Enum: "UNSET" "AWS*ECR" "GOOGLE*GCR"
        """
        return pulumi.get(self, "gen_type")

    @gen_type.setter
    def gen_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "gen_type", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Organization identifier of the GitOps repository.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Project identifier of the GitOps repository.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="refreshInterval")
    def refresh_interval(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        For OCI repos, this is the interval to refresh the token to access the registry.
        """
        return pulumi.get(self, "refresh_interval")

    @refresh_interval.setter
    def refresh_interval(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "refresh_interval", value)

    @_builtins.property
    @pulumi.getter(name="updateMasks")
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release.""")
    def update_masks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GitOpsRepositoryUpdateMaskArgs']]]]:
        """
        Update mask of the repository.
        """
        return pulumi.get(self, "update_masks")

    @update_masks.setter
    def update_masks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GitOpsRepositoryUpdateMaskArgs']]]]):
        pulumi.set(self, "update_masks", value)

    @_builtins.property
    @pulumi.getter
    def upsert(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates if the GitOps repository should be updated if existing and inserted if not.
        """
        return pulumi.get(self, "upsert")

    @upsert.setter
    def upsert(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "upsert", value)


@pulumi.input_type
class _GitOpsRepositoryState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 agent_id: Optional[pulumi.Input[_builtins.str]] = None,
                 creds_only: Optional[pulumi.Input[_builtins.bool]] = None,
                 ecr_gen: Optional[pulumi.Input['GitOpsRepositoryEcrGenArgs']] = None,
                 force_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 gcr_gen: Optional[pulumi.Input['GitOpsRepositoryGcrGenArgs']] = None,
                 gen_type: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 refresh_interval: Optional[pulumi.Input[_builtins.str]] = None,
                 repos: Optional[pulumi.Input[Sequence[pulumi.Input['GitOpsRepositoryRepoArgs']]]] = None,
                 update_masks: Optional[pulumi.Input[Sequence[pulumi.Input['GitOpsRepositoryUpdateMaskArgs']]]] = None,
                 upsert: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        Input properties used for looking up and filtering GitOpsRepository resources.
        :param pulumi.Input[_builtins.str] account_id: Account identifier of the GitOps repository.
        :param pulumi.Input[_builtins.str] agent_id: Agent identifier of the GitOps repository.
        :param pulumi.Input[_builtins.bool] creds_only: Indicates if to operate on credential set instead of repository.
        :param pulumi.Input['GitOpsRepositoryEcrGenArgs'] ecr_gen: ECR access token generator specific configuration.
        :param pulumi.Input[_builtins.bool] force_delete: Indicates if the repository should be deleted forcefully, regardless of existing applications using that repo.
        :param pulumi.Input['GitOpsRepositoryGcrGenArgs'] gcr_gen: GCR access token generator specific configuration.
        :param pulumi.Input[_builtins.str] gen_type: Default: "UNSET"
               Enum: "UNSET" "AWS*ECR" "GOOGLE*GCR"
        :param pulumi.Input[_builtins.str] identifier: Identifier of the GitOps repository.
        :param pulumi.Input[_builtins.str] org_id: Organization identifier of the GitOps repository.
        :param pulumi.Input[_builtins.str] project_id: Project identifier of the GitOps repository.
        :param pulumi.Input[_builtins.str] refresh_interval: For OCI repos, this is the interval to refresh the token to access the registry.
        :param pulumi.Input[Sequence[pulumi.Input['GitOpsRepositoryRepoArgs']]] repos: Repo details holding application configurations.
        :param pulumi.Input[Sequence[pulumi.Input['GitOpsRepositoryUpdateMaskArgs']]] update_masks: Update mask of the repository.
        :param pulumi.Input[_builtins.bool] upsert: Indicates if the GitOps repository should be updated if existing and inserted if not.
        """
        if account_id is not None:
            warnings.warn("""This field is deprecated and will be removed in a future release.""", DeprecationWarning)
            pulumi.log.warn("""account_id is deprecated: This field is deprecated and will be removed in a future release.""")
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if agent_id is not None:
            pulumi.set(__self__, "agent_id", agent_id)
        if creds_only is not None:
            pulumi.set(__self__, "creds_only", creds_only)
        if ecr_gen is not None:
            pulumi.set(__self__, "ecr_gen", ecr_gen)
        if force_delete is not None:
            pulumi.set(__self__, "force_delete", force_delete)
        if gcr_gen is not None:
            pulumi.set(__self__, "gcr_gen", gcr_gen)
        if gen_type is not None:
            pulumi.set(__self__, "gen_type", gen_type)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if refresh_interval is not None:
            pulumi.set(__self__, "refresh_interval", refresh_interval)
        if repos is not None:
            pulumi.set(__self__, "repos", repos)
        if update_masks is not None:
            warnings.warn("""This field is deprecated and will be removed in a future release.""", DeprecationWarning)
            pulumi.log.warn("""update_masks is deprecated: This field is deprecated and will be removed in a future release.""")
        if update_masks is not None:
            pulumi.set(__self__, "update_masks", update_masks)
        if upsert is not None:
            pulumi.set(__self__, "upsert", upsert)

    @_builtins.property
    @pulumi.getter(name="accountId")
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release.""")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Account identifier of the GitOps repository.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter(name="agentId")
    def agent_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Agent identifier of the GitOps repository.
        """
        return pulumi.get(self, "agent_id")

    @agent_id.setter
    def agent_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "agent_id", value)

    @_builtins.property
    @pulumi.getter(name="credsOnly")
    def creds_only(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates if to operate on credential set instead of repository.
        """
        return pulumi.get(self, "creds_only")

    @creds_only.setter
    def creds_only(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "creds_only", value)

    @_builtins.property
    @pulumi.getter(name="ecrGen")
    def ecr_gen(self) -> Optional[pulumi.Input['GitOpsRepositoryEcrGenArgs']]:
        """
        ECR access token generator specific configuration.
        """
        return pulumi.get(self, "ecr_gen")

    @ecr_gen.setter
    def ecr_gen(self, value: Optional[pulumi.Input['GitOpsRepositoryEcrGenArgs']]):
        pulumi.set(self, "ecr_gen", value)

    @_builtins.property
    @pulumi.getter(name="forceDelete")
    def force_delete(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates if the repository should be deleted forcefully, regardless of existing applications using that repo.
        """
        return pulumi.get(self, "force_delete")

    @force_delete.setter
    def force_delete(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "force_delete", value)

    @_builtins.property
    @pulumi.getter(name="gcrGen")
    def gcr_gen(self) -> Optional[pulumi.Input['GitOpsRepositoryGcrGenArgs']]:
        """
        GCR access token generator specific configuration.
        """
        return pulumi.get(self, "gcr_gen")

    @gcr_gen.setter
    def gcr_gen(self, value: Optional[pulumi.Input['GitOpsRepositoryGcrGenArgs']]):
        pulumi.set(self, "gcr_gen", value)

    @_builtins.property
    @pulumi.getter(name="genType")
    def gen_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Default: "UNSET"
        Enum: "UNSET" "AWS*ECR" "GOOGLE*GCR"
        """
        return pulumi.get(self, "gen_type")

    @gen_type.setter
    def gen_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "gen_type", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifier of the GitOps repository.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Organization identifier of the GitOps repository.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Project identifier of the GitOps repository.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="refreshInterval")
    def refresh_interval(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        For OCI repos, this is the interval to refresh the token to access the registry.
        """
        return pulumi.get(self, "refresh_interval")

    @refresh_interval.setter
    def refresh_interval(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "refresh_interval", value)

    @_builtins.property
    @pulumi.getter
    def repos(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GitOpsRepositoryRepoArgs']]]]:
        """
        Repo details holding application configurations.
        """
        return pulumi.get(self, "repos")

    @repos.setter
    def repos(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GitOpsRepositoryRepoArgs']]]]):
        pulumi.set(self, "repos", value)

    @_builtins.property
    @pulumi.getter(name="updateMasks")
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release.""")
    def update_masks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GitOpsRepositoryUpdateMaskArgs']]]]:
        """
        Update mask of the repository.
        """
        return pulumi.get(self, "update_masks")

    @update_masks.setter
    def update_masks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GitOpsRepositoryUpdateMaskArgs']]]]):
        pulumi.set(self, "update_masks", value)

    @_builtins.property
    @pulumi.getter
    def upsert(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates if the GitOps repository should be updated if existing and inserted if not.
        """
        return pulumi.get(self, "upsert")

    @upsert.setter
    def upsert(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "upsert", value)


@pulumi.type_token("harness:platform/gitOpsRepository:GitOpsRepository")
class GitOpsRepository(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 agent_id: Optional[pulumi.Input[_builtins.str]] = None,
                 creds_only: Optional[pulumi.Input[_builtins.bool]] = None,
                 ecr_gen: Optional[pulumi.Input[Union['GitOpsRepositoryEcrGenArgs', 'GitOpsRepositoryEcrGenArgsDict']]] = None,
                 force_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 gcr_gen: Optional[pulumi.Input[Union['GitOpsRepositoryGcrGenArgs', 'GitOpsRepositoryGcrGenArgsDict']]] = None,
                 gen_type: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 refresh_interval: Optional[pulumi.Input[_builtins.str]] = None,
                 repos: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GitOpsRepositoryRepoArgs', 'GitOpsRepositoryRepoArgsDict']]]]] = None,
                 update_masks: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GitOpsRepositoryUpdateMaskArgs', 'GitOpsRepositoryUpdateMaskArgsDict']]]]] = None,
                 upsert: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        """
        Resource for managing Harness Gitops Repository.

        ## Import

        The `pulumi import` command can be used, for example:

        Import an Account level Gitops Repository

        ```sh
        $ pulumi import harness:platform/gitOpsRepository:GitOpsRepository example <agent_id>/<respository_id>
        ```

        Import an Org level Gitops Repository

        ```sh
        $ pulumi import harness:platform/gitOpsRepository:GitOpsRepository example <organization_id>/<agent_id>/<respository_id>
        ```

        Import a Project level Gitops Repository

        ```sh
        $ pulumi import harness:platform/gitOpsRepository:GitOpsRepository example <organization_id>/<project_id>/<agent_id>/<respository_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: Account identifier of the GitOps repository.
        :param pulumi.Input[_builtins.str] agent_id: Agent identifier of the GitOps repository.
        :param pulumi.Input[_builtins.bool] creds_only: Indicates if to operate on credential set instead of repository.
        :param pulumi.Input[Union['GitOpsRepositoryEcrGenArgs', 'GitOpsRepositoryEcrGenArgsDict']] ecr_gen: ECR access token generator specific configuration.
        :param pulumi.Input[_builtins.bool] force_delete: Indicates if the repository should be deleted forcefully, regardless of existing applications using that repo.
        :param pulumi.Input[Union['GitOpsRepositoryGcrGenArgs', 'GitOpsRepositoryGcrGenArgsDict']] gcr_gen: GCR access token generator specific configuration.
        :param pulumi.Input[_builtins.str] gen_type: Default: "UNSET"
               Enum: "UNSET" "AWS*ECR" "GOOGLE*GCR"
        :param pulumi.Input[_builtins.str] identifier: Identifier of the GitOps repository.
        :param pulumi.Input[_builtins.str] org_id: Organization identifier of the GitOps repository.
        :param pulumi.Input[_builtins.str] project_id: Project identifier of the GitOps repository.
        :param pulumi.Input[_builtins.str] refresh_interval: For OCI repos, this is the interval to refresh the token to access the registry.
        :param pulumi.Input[Sequence[pulumi.Input[Union['GitOpsRepositoryRepoArgs', 'GitOpsRepositoryRepoArgsDict']]]] repos: Repo details holding application configurations.
        :param pulumi.Input[Sequence[pulumi.Input[Union['GitOpsRepositoryUpdateMaskArgs', 'GitOpsRepositoryUpdateMaskArgsDict']]]] update_masks: Update mask of the repository.
        :param pulumi.Input[_builtins.bool] upsert: Indicates if the GitOps repository should be updated if existing and inserted if not.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GitOpsRepositoryArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for managing Harness Gitops Repository.

        ## Import

        The `pulumi import` command can be used, for example:

        Import an Account level Gitops Repository

        ```sh
        $ pulumi import harness:platform/gitOpsRepository:GitOpsRepository example <agent_id>/<respository_id>
        ```

        Import an Org level Gitops Repository

        ```sh
        $ pulumi import harness:platform/gitOpsRepository:GitOpsRepository example <organization_id>/<agent_id>/<respository_id>
        ```

        Import a Project level Gitops Repository

        ```sh
        $ pulumi import harness:platform/gitOpsRepository:GitOpsRepository example <organization_id>/<project_id>/<agent_id>/<respository_id>
        ```

        :param str resource_name: The name of the resource.
        :param GitOpsRepositoryArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GitOpsRepositoryArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 agent_id: Optional[pulumi.Input[_builtins.str]] = None,
                 creds_only: Optional[pulumi.Input[_builtins.bool]] = None,
                 ecr_gen: Optional[pulumi.Input[Union['GitOpsRepositoryEcrGenArgs', 'GitOpsRepositoryEcrGenArgsDict']]] = None,
                 force_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 gcr_gen: Optional[pulumi.Input[Union['GitOpsRepositoryGcrGenArgs', 'GitOpsRepositoryGcrGenArgsDict']]] = None,
                 gen_type: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 refresh_interval: Optional[pulumi.Input[_builtins.str]] = None,
                 repos: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GitOpsRepositoryRepoArgs', 'GitOpsRepositoryRepoArgsDict']]]]] = None,
                 update_masks: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GitOpsRepositoryUpdateMaskArgs', 'GitOpsRepositoryUpdateMaskArgsDict']]]]] = None,
                 upsert: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GitOpsRepositoryArgs.__new__(GitOpsRepositoryArgs)

            __props__.__dict__["account_id"] = account_id
            if agent_id is None and not opts.urn:
                raise TypeError("Missing required property 'agent_id'")
            __props__.__dict__["agent_id"] = agent_id
            __props__.__dict__["creds_only"] = creds_only
            __props__.__dict__["ecr_gen"] = ecr_gen
            __props__.__dict__["force_delete"] = force_delete
            __props__.__dict__["gcr_gen"] = gcr_gen
            __props__.__dict__["gen_type"] = gen_type
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["refresh_interval"] = refresh_interval
            if repos is None and not opts.urn:
                raise TypeError("Missing required property 'repos'")
            __props__.__dict__["repos"] = repos
            __props__.__dict__["update_masks"] = update_masks
            __props__.__dict__["upsert"] = upsert
        super(GitOpsRepository, __self__).__init__(
            'harness:platform/gitOpsRepository:GitOpsRepository',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[_builtins.str]] = None,
            agent_id: Optional[pulumi.Input[_builtins.str]] = None,
            creds_only: Optional[pulumi.Input[_builtins.bool]] = None,
            ecr_gen: Optional[pulumi.Input[Union['GitOpsRepositoryEcrGenArgs', 'GitOpsRepositoryEcrGenArgsDict']]] = None,
            force_delete: Optional[pulumi.Input[_builtins.bool]] = None,
            gcr_gen: Optional[pulumi.Input[Union['GitOpsRepositoryGcrGenArgs', 'GitOpsRepositoryGcrGenArgsDict']]] = None,
            gen_type: Optional[pulumi.Input[_builtins.str]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            refresh_interval: Optional[pulumi.Input[_builtins.str]] = None,
            repos: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GitOpsRepositoryRepoArgs', 'GitOpsRepositoryRepoArgsDict']]]]] = None,
            update_masks: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GitOpsRepositoryUpdateMaskArgs', 'GitOpsRepositoryUpdateMaskArgsDict']]]]] = None,
            upsert: Optional[pulumi.Input[_builtins.bool]] = None) -> 'GitOpsRepository':
        """
        Get an existing GitOpsRepository resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: Account identifier of the GitOps repository.
        :param pulumi.Input[_builtins.str] agent_id: Agent identifier of the GitOps repository.
        :param pulumi.Input[_builtins.bool] creds_only: Indicates if to operate on credential set instead of repository.
        :param pulumi.Input[Union['GitOpsRepositoryEcrGenArgs', 'GitOpsRepositoryEcrGenArgsDict']] ecr_gen: ECR access token generator specific configuration.
        :param pulumi.Input[_builtins.bool] force_delete: Indicates if the repository should be deleted forcefully, regardless of existing applications using that repo.
        :param pulumi.Input[Union['GitOpsRepositoryGcrGenArgs', 'GitOpsRepositoryGcrGenArgsDict']] gcr_gen: GCR access token generator specific configuration.
        :param pulumi.Input[_builtins.str] gen_type: Default: "UNSET"
               Enum: "UNSET" "AWS*ECR" "GOOGLE*GCR"
        :param pulumi.Input[_builtins.str] identifier: Identifier of the GitOps repository.
        :param pulumi.Input[_builtins.str] org_id: Organization identifier of the GitOps repository.
        :param pulumi.Input[_builtins.str] project_id: Project identifier of the GitOps repository.
        :param pulumi.Input[_builtins.str] refresh_interval: For OCI repos, this is the interval to refresh the token to access the registry.
        :param pulumi.Input[Sequence[pulumi.Input[Union['GitOpsRepositoryRepoArgs', 'GitOpsRepositoryRepoArgsDict']]]] repos: Repo details holding application configurations.
        :param pulumi.Input[Sequence[pulumi.Input[Union['GitOpsRepositoryUpdateMaskArgs', 'GitOpsRepositoryUpdateMaskArgsDict']]]] update_masks: Update mask of the repository.
        :param pulumi.Input[_builtins.bool] upsert: Indicates if the GitOps repository should be updated if existing and inserted if not.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GitOpsRepositoryState.__new__(_GitOpsRepositoryState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["agent_id"] = agent_id
        __props__.__dict__["creds_only"] = creds_only
        __props__.__dict__["ecr_gen"] = ecr_gen
        __props__.__dict__["force_delete"] = force_delete
        __props__.__dict__["gcr_gen"] = gcr_gen
        __props__.__dict__["gen_type"] = gen_type
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["refresh_interval"] = refresh_interval
        __props__.__dict__["repos"] = repos
        __props__.__dict__["update_masks"] = update_masks
        __props__.__dict__["upsert"] = upsert
        return GitOpsRepository(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accountId")
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release.""")
    def account_id(self) -> pulumi.Output[_builtins.str]:
        """
        Account identifier of the GitOps repository.
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter(name="agentId")
    def agent_id(self) -> pulumi.Output[_builtins.str]:
        """
        Agent identifier of the GitOps repository.
        """
        return pulumi.get(self, "agent_id")

    @_builtins.property
    @pulumi.getter(name="credsOnly")
    def creds_only(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Indicates if to operate on credential set instead of repository.
        """
        return pulumi.get(self, "creds_only")

    @_builtins.property
    @pulumi.getter(name="ecrGen")
    def ecr_gen(self) -> pulumi.Output[Optional['outputs.GitOpsRepositoryEcrGen']]:
        """
        ECR access token generator specific configuration.
        """
        return pulumi.get(self, "ecr_gen")

    @_builtins.property
    @pulumi.getter(name="forceDelete")
    def force_delete(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Indicates if the repository should be deleted forcefully, regardless of existing applications using that repo.
        """
        return pulumi.get(self, "force_delete")

    @_builtins.property
    @pulumi.getter(name="gcrGen")
    def gcr_gen(self) -> pulumi.Output[Optional['outputs.GitOpsRepositoryGcrGen']]:
        """
        GCR access token generator specific configuration.
        """
        return pulumi.get(self, "gcr_gen")

    @_builtins.property
    @pulumi.getter(name="genType")
    def gen_type(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Default: "UNSET"
        Enum: "UNSET" "AWS*ECR" "GOOGLE*GCR"
        """
        return pulumi.get(self, "gen_type")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Identifier of the GitOps repository.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Organization identifier of the GitOps repository.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Project identifier of the GitOps repository.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="refreshInterval")
    def refresh_interval(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        For OCI repos, this is the interval to refresh the token to access the registry.
        """
        return pulumi.get(self, "refresh_interval")

    @_builtins.property
    @pulumi.getter
    def repos(self) -> pulumi.Output[Sequence['outputs.GitOpsRepositoryRepo']]:
        """
        Repo details holding application configurations.
        """
        return pulumi.get(self, "repos")

    @_builtins.property
    @pulumi.getter(name="updateMasks")
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release.""")
    def update_masks(self) -> pulumi.Output[Optional[Sequence['outputs.GitOpsRepositoryUpdateMask']]]:
        """
        Update mask of the repository.
        """
        return pulumi.get(self, "update_masks")

    @_builtins.property
    @pulumi.getter
    def upsert(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Indicates if the GitOps repository should be updated if existing and inserted if not.
        """
        return pulumi.get(self, "upsert")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DiscoverySettingArgs', 'DiscoverySetting']

@pulumi.input_type
class DiscoverySettingArgs:
    def __init__(__self__, *,
                 correlation_id: Optional[pulumi.Input[_builtins.str]] = None,
                 image_registry: Optional[pulumi.Input['DiscoverySettingImageRegistryArgs']] = None,
                 org_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 project_identifier: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a DiscoverySetting resource.
        :param pulumi.Input[_builtins.str] correlation_id: Correlation ID for the request.
        :param pulumi.Input['DiscoverySettingImageRegistryArgs'] image_registry: Image registry configuration.
        :param pulumi.Input[_builtins.str] org_identifier: The organization identifier.
        :param pulumi.Input[_builtins.str] project_identifier: The project identifier.
        """
        if correlation_id is not None:
            pulumi.set(__self__, "correlation_id", correlation_id)
        if image_registry is not None:
            pulumi.set(__self__, "image_registry", image_registry)
        if org_identifier is not None:
            pulumi.set(__self__, "org_identifier", org_identifier)
        if project_identifier is not None:
            pulumi.set(__self__, "project_identifier", project_identifier)

    @_builtins.property
    @pulumi.getter(name="correlationId")
    def correlation_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Correlation ID for the request.
        """
        return pulumi.get(self, "correlation_id")

    @correlation_id.setter
    def correlation_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "correlation_id", value)

    @_builtins.property
    @pulumi.getter(name="imageRegistry")
    def image_registry(self) -> Optional[pulumi.Input['DiscoverySettingImageRegistryArgs']]:
        """
        Image registry configuration.
        """
        return pulumi.get(self, "image_registry")

    @image_registry.setter
    def image_registry(self, value: Optional[pulumi.Input['DiscoverySettingImageRegistryArgs']]):
        pulumi.set(self, "image_registry", value)

    @_builtins.property
    @pulumi.getter(name="orgIdentifier")
    def org_identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The organization identifier.
        """
        return pulumi.get(self, "org_identifier")

    @org_identifier.setter
    def org_identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_identifier", value)

    @_builtins.property
    @pulumi.getter(name="projectIdentifier")
    def project_identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The project identifier.
        """
        return pulumi.get(self, "project_identifier")

    @project_identifier.setter
    def project_identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_identifier", value)


@pulumi.input_type
class _DiscoverySettingState:
    def __init__(__self__, *,
                 correlation_id: Optional[pulumi.Input[_builtins.str]] = None,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 image_registry: Optional[pulumi.Input['DiscoverySettingImageRegistryArgs']] = None,
                 org_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 project_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering DiscoverySetting resources.
        :param pulumi.Input[_builtins.str] correlation_id: Correlation ID for the request.
        :param pulumi.Input[_builtins.str] created_at: Timestamp when the setting was created.
        :param pulumi.Input['DiscoverySettingImageRegistryArgs'] image_registry: Image registry configuration.
        :param pulumi.Input[_builtins.str] org_identifier: The organization identifier.
        :param pulumi.Input[_builtins.str] project_identifier: The project identifier.
        :param pulumi.Input[_builtins.str] updated_at: Timestamp when the setting was last updated.
        """
        if correlation_id is not None:
            pulumi.set(__self__, "correlation_id", correlation_id)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if image_registry is not None:
            pulumi.set(__self__, "image_registry", image_registry)
        if org_identifier is not None:
            pulumi.set(__self__, "org_identifier", org_identifier)
        if project_identifier is not None:
            pulumi.set(__self__, "project_identifier", project_identifier)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @_builtins.property
    @pulumi.getter(name="correlationId")
    def correlation_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Correlation ID for the request.
        """
        return pulumi.get(self, "correlation_id")

    @correlation_id.setter
    def correlation_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "correlation_id", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Timestamp when the setting was created.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="imageRegistry")
    def image_registry(self) -> Optional[pulumi.Input['DiscoverySettingImageRegistryArgs']]:
        """
        Image registry configuration.
        """
        return pulumi.get(self, "image_registry")

    @image_registry.setter
    def image_registry(self, value: Optional[pulumi.Input['DiscoverySettingImageRegistryArgs']]):
        pulumi.set(self, "image_registry", value)

    @_builtins.property
    @pulumi.getter(name="orgIdentifier")
    def org_identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The organization identifier.
        """
        return pulumi.get(self, "org_identifier")

    @org_identifier.setter
    def org_identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_identifier", value)

    @_builtins.property
    @pulumi.getter(name="projectIdentifier")
    def project_identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The project identifier.
        """
        return pulumi.get(self, "project_identifier")

    @project_identifier.setter
    def project_identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_identifier", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Timestamp when the setting was last updated.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_at", value)


@pulumi.type_token("harness:service/discoverySetting:DiscoverySetting")
class DiscoverySetting(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 correlation_id: Optional[pulumi.Input[_builtins.str]] = None,
                 image_registry: Optional[pulumi.Input[Union['DiscoverySettingImageRegistryArgs', 'DiscoverySettingImageRegistryArgsDict']]] = None,
                 org_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 project_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for managing service discovery settings.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        # Update image registry settings for service discovery
        example = harness.service.DiscoverySetting("example",
            org_identifier="sechaosworkshop",
            project_identifier="se1",
            image_registry={
                "account": "<account_name>",
                "server": "<registry_server>",
                "secrets": ["<secret_name>"],
            })
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] correlation_id: Correlation ID for the request.
        :param pulumi.Input[Union['DiscoverySettingImageRegistryArgs', 'DiscoverySettingImageRegistryArgsDict']] image_registry: Image registry configuration.
        :param pulumi.Input[_builtins.str] org_identifier: The organization identifier.
        :param pulumi.Input[_builtins.str] project_identifier: The project identifier.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[DiscoverySettingArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for managing service discovery settings.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        # Update image registry settings for service discovery
        example = harness.service.DiscoverySetting("example",
            org_identifier="sechaosworkshop",
            project_identifier="se1",
            image_registry={
                "account": "<account_name>",
                "server": "<registry_server>",
                "secrets": ["<secret_name>"],
            })
        ```

        :param str resource_name: The name of the resource.
        :param DiscoverySettingArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DiscoverySettingArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 correlation_id: Optional[pulumi.Input[_builtins.str]] = None,
                 image_registry: Optional[pulumi.Input[Union['DiscoverySettingImageRegistryArgs', 'DiscoverySettingImageRegistryArgsDict']]] = None,
                 org_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 project_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DiscoverySettingArgs.__new__(DiscoverySettingArgs)

            __props__.__dict__["correlation_id"] = correlation_id
            __props__.__dict__["image_registry"] = image_registry
            __props__.__dict__["org_identifier"] = org_identifier
            __props__.__dict__["project_identifier"] = project_identifier
            __props__.__dict__["created_at"] = None
            __props__.__dict__["updated_at"] = None
        super(DiscoverySetting, __self__).__init__(
            'harness:service/discoverySetting:DiscoverySetting',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            correlation_id: Optional[pulumi.Input[_builtins.str]] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            image_registry: Optional[pulumi.Input[Union['DiscoverySettingImageRegistryArgs', 'DiscoverySettingImageRegistryArgsDict']]] = None,
            org_identifier: Optional[pulumi.Input[_builtins.str]] = None,
            project_identifier: Optional[pulumi.Input[_builtins.str]] = None,
            updated_at: Optional[pulumi.Input[_builtins.str]] = None) -> 'DiscoverySetting':
        """
        Get an existing DiscoverySetting resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] correlation_id: Correlation ID for the request.
        :param pulumi.Input[_builtins.str] created_at: Timestamp when the setting was created.
        :param pulumi.Input[Union['DiscoverySettingImageRegistryArgs', 'DiscoverySettingImageRegistryArgsDict']] image_registry: Image registry configuration.
        :param pulumi.Input[_builtins.str] org_identifier: The organization identifier.
        :param pulumi.Input[_builtins.str] project_identifier: The project identifier.
        :param pulumi.Input[_builtins.str] updated_at: Timestamp when the setting was last updated.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DiscoverySettingState.__new__(_DiscoverySettingState)

        __props__.__dict__["correlation_id"] = correlation_id
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["image_registry"] = image_registry
        __props__.__dict__["org_identifier"] = org_identifier
        __props__.__dict__["project_identifier"] = project_identifier
        __props__.__dict__["updated_at"] = updated_at
        return DiscoverySetting(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="correlationId")
    def correlation_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Correlation ID for the request.
        """
        return pulumi.get(self, "correlation_id")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        Timestamp when the setting was created.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="imageRegistry")
    def image_registry(self) -> pulumi.Output[Optional['outputs.DiscoverySettingImageRegistry']]:
        """
        Image registry configuration.
        """
        return pulumi.get(self, "image_registry")

    @_builtins.property
    @pulumi.getter(name="orgIdentifier")
    def org_identifier(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The organization identifier.
        """
        return pulumi.get(self, "org_identifier")

    @_builtins.property
    @pulumi.getter(name="projectIdentifier")
    def project_identifier(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The project identifier.
        """
        return pulumi.get(self, "project_identifier")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.str]:
        """
        Timestamp when the setting was last updated.
        """
        return pulumi.get(self, "updated_at")

